@@ -9,32 +9,29 @@ from typing import Tuple
 from typing import Union
 from typing import Callable
 from typing import Optional
-from cfdata.tabular import TabularDataset
 
 
+arr_type = Union[np.ndarray, torch.Tensor]
+data_type = Optional[Union[np.ndarray, str]]
 param_type = Union[torch.Tensor, torch.nn.Parameter]
-data_type = Optional[Union[np.ndarray, List[List[float]], str]]
+configs_type = Optional[Union[List[Dict[str, Any]], Dict[str, Any]]]
+general_config_type = Optional[Union[str, Dict[str, Any]]]
 np_dict_type = Dict[str, Union[np.ndarray, Any]]
 tensor_dict_type = Dict[str, Union[torch.Tensor, Any]]
-tensor_tuple_type = Tuple[torch.Tensor, torch.Tensor]
-general_config_type = Optional[Union[str, Dict[str, Any]]]
-predictor_type = Optional[Callable[[int, TabularDataset, np.ndarray], np.ndarray]]
-evaluator_type = Optional[Callable[[List[np.ndarray], List[np.ndarray]], np.ndarray]]
-prefetch_batch_type = Tuple[tensor_dict_type, Optional[torch.Tensor]]
-loader_batch_type = Union[tensor_dict_type, prefetch_batch_type]
 losses_type = Union[torch.Tensor, tensor_dict_type]
+states_callback_type = Optional[Callable[[Any, Dict[str, Any]], Dict[str, Any]]]
+sample_weights_type = Optional[Union[np.ndarray, Tuple[np.ndarray, np.ndarray]]]
 
 
 __all__ = [
-    "param_type",
+    "arr_type",
     "data_type",
+    "param_type",
+    "configs_type",
+    "general_config_type",
     "np_dict_type",
     "tensor_dict_type",
-    "tensor_tuple_type",
-    "general_config_type",
-    "predictor_type",
-    "evaluator_type",
-    "prefetch_batch_type",
-    "loader_batch_type",
     "losses_type",
+    "states_callback_type",
+    "sample_weights_type",
 ]
